This function returns a database motif specification.
We use GlycoMotif collections
(https://glycomotif.glyomics.org/glycomotif/GlycoMotif)
as the source of the motifs.
This function is useful to be integrated with have_motifs() and count_motifs().
For example, use have_motifs(glycans, db_motifs()) to check against the
default GlyGen motif collection, or pass source_id to use another
collection.
Arguments
- source_id
A character vector of motif collection identifiers to use. Defaults to
"GGM"for backward compatibility. Usedplyr::distinct(db_motif_info(), source_id, source)to get all available sources. You can use more than one motif collections likec("GGM", "CCRC"). To use all available motifs, use the"GM"collection directly.
Details
Use db_motif_info() to inspect the motifs included in the database.
You can use dplyr::distinct(db_motif_info(), source_id, source) to get
all available sources.
Data source and license
The bundled annotations are derived from the
GlycoMotif
resource. GlyGen distributes its database sets under the
Creative Commons Attribution 4.0 International license. See the package COPYRIGHTS
file for attribution and snapshot details.